Data include time series of Northeast U.S. community scores for community commercial fishing revenue sensitivity to temperature, ocean acidification, stock size/status, total sensitivity, and total vulnerability based on Hare et al. 2016. species vulnerability.
Format
273424 rows and 5 columns.
Time: Year.
Var: Community, State-climate vulnerability indicator.
Value: Value of Community Risk indicator.
EPU: Region where sampling occurred: NE New England, MAB Mid-Atlantic.
Units: Units of Community Risk indicator.
Details
Reciprocal Simpson's Diversity scores for each community, Regional Quotients, and Regional Community vulnerability scores are also included. More information including processing and indicator derivation steps are available at https://noaa-edab.github.io/tech-doc/community-climate-vulnerability.html.