The crew survey is an intercept survey that evaluates demographic and job satisfaction information of crew and hired captains
Format
A data set containing 3048 rows and 7 columns.
Time: Year
Value: Value of Metric
Var: Short-hand survey question name.
Var.long: original survey question name.
Var.Answer: categorical answer to question
Metric: metric evaluated for each question
EPU: Ecological Production Unit (EPU) where data originated. Here "MAB" refers to the Mid-Atlantic Bight.
Details
More information available at https://noaa-edab.github.io/tech-doc/crew_survey.html