EcoMon Zooplankton Principal Components: Zooplankton community composition on the Northeast US Continental Shelf
Estimated zooplankton diversity on the Northeast US Continental Shelf.
Format
284 rows and 5 columns.
Var: Principal Components
Value: Value of variable
Var.Units: Units of variable
Var.EPU: Ecological Production Units where data originated.
Time: Year.
129 rows and 5 columns.
Var: Shannon diversity.
Value: Value of variable
Var.Units: Units of variable
Var.EPU: Ecological Production Units where data originated.
Time: Year.
Details
These data represent an ecosystem-level look at zooplankton community composition using the dimension reduction technique of principal component analysis.
These data were derived from bimonthly Ecosystem Monitoring (EcoMon) cruises throughout the Northeast US Continental Shelf, and represent a different estimation method than what is found in the zooplankton anomaly data set. Specifically, abundance anomalies were interpolated following an ordinary kriging approach by season across the Northeast Shelf Ecosystem. Exact methods used to derived these data are available at https://noaa-edab.github.io/ECSA/.